Learn R Programming

corrsieve (version 1.6-9)

QmatrixFilt: QmatrixFilt

Description

The S4 class QmatrixFilt lists for Q matrix correlation output

Arguments

Objects from the Class

Objects can be created by calls of the form new("QmatrixFilt", ...).

Slots

rowncol

A list listing filtered Q matrix correlations by the rows-and-columns method

avmaxcorr

A table listing filtered Q matrix correlations by the rows-and-columns method

rawcorr

A list listing raw Q matrix correlations

See Also

QmatrixFilt