Calculates Q matrix correlations from structure files in the folder specified in the filepath option
corr.Qmatrix(filepath = "./", instruct = FALSE, rowncol = TRUE,
avmax = TRUE, pvalue = FALSE, raw = TRUE, r = 0.99, p = 0.05)a character string listing the folder's path from the current directory
when TRUE, data is in INSTRUCT format, else data is in STRUCTURE format
when TRUE, calculates and returns filtered Q matrix correlations using the rows-and-columns criterion
when TRUE, calculates and returns filtered Q matrix correlations using the average maximum correlation criterion
when TRUE, calculates and returns Q matrix correlations using permutation tests
when TRUE, returns the raw unfiltered Q matrix correlations
the minimum r value to classify a correlation as significant
the maximum p value to classify a correlation as significant. Ignored unless pvalue = TRUE
Returns a S4 object of class QmatrixFilt listing Q matrix correlation results for all STRUCTURE results files in the designated folder