Learn R Programming

corrsieve (version 1.6-9)

matrixCorr: MatrixCorr

Description

The S4 class matrixCorr lists raw, unfiltered Q matrices between Structure runs

Arguments

Objects from the Class

Objects can be created by calls of the form new("matrixCorr", ...).

Slots

K

A numeric listing the K value of the runs correlated

Run1

A numeric identifying the first of the runs correlated

Run2

A numeric identifying the second of the runs correlated

CorrMatrix

A matrix listing raw Q matrix correlations

Pvalues

A matrix listing raw Q matrix correlation significances

See Also

matrixCorr