powered by
The S4 class QmatrixFilt lists for Q matrix correlation output
Objects can be created by calls of the form new("QmatrixFilt", ...).
new("QmatrixFilt", ...)
A list listing filtered Q matrix correlations by the rows-and-columns method
A table listing filtered Q matrix correlations by the rows-and-columns method
A list listing raw Q matrix correlations
QmatrixFilt