powered by
The S4 class matrixCorr lists raw, unfiltered Q matrices between Structure runs
Objects can be created by calls of the form new("matrixCorr", ...).
new("matrixCorr", ...)
A numeric listing the K value of the runs correlated
A numeric identifying the first of the runs correlated
A numeric identifying the second of the runs correlated
A matrix listing raw Q matrix correlations
A matrix listing raw Q matrix correlation significances
matrixCorr